package com.cultural.heritage.model.dto.order;

import com.cultural.heritage.model.dto.snapshot.AddressSnapshot;
import com.cultural.heritage.model.dto.snapshot.ContactsSnapshot;
import com.cultural.heritage.model.dto.snapshot.CouponSnapshot;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;

@Data
@Schema(description = "订单添加请求体", requiredProperties = {"userId", "orderNumber", "addressSnapshot", "contactsSnapshot",
"couponSnapshot", "totalAmount", "orderStatus"})
public class OrderAddRequest implements Serializable {


    /**
     * 用户id
     */
    @Schema(description = "用户id(id > 0)", example = "2")
    private Long userId;

    /**
     * 订单编号
     */
    @Schema(description = "订单编号", example = "20241105342838428324834")
    private String orderNumber;


    /**
     * 地址信息快照
     */
    @Schema(description = "订单地址信息")
    private AddressSnapshot addressSnapshot;


    /**
     * 联系人信息快照
     */
    @Schema(description = "订单联系人信息")
    private ContactsSnapshot contactsSnapshot;


    /**
     * 优惠券信息快照
     */
    @Schema(description = "订单优惠券信息")
    private CouponSnapshot couponSnapshot;


    /**
     * 订单总金额
     */
    @Schema(description = "订单总金额", example = "500")
    private Double totalAmount;

    /**
     * 订单状态
     */
    @Schema(description = "订单状态", example = "待发货")
    private String orderStatus;


    @Serial
    private static final long serialVersionUID = 1L;
}
